==> metamanager-0.2.1.tgz: package/index.js <==
var MetaManager = function(jqtpl) {
	
	var _stack = [];
	var _title = '';
	var _charset = 'utf-8';
	var _tmpl = '<head>\n<title>${title}</title>\n'
		+'{{each(i,tag) tags}}'
		+'  <${tag}{{each(key,value) attributes}}{{if value != null}} ${key}="${value}"{{/if}}{{/each}}>{{if close}}</${tag}>{{/if}}\n{{/each}}'
		+'</head>';
	
	jqtpl.template( "headingTemplate",_tmpl);

	function tagExists(tag,key,value) {
		return false;
		}
	
	return {
				
		get: function() {
			return _stack;
			},
		
		render: function() {
			
			// add standard tags
			if (!tagExists('meta','charset'))
				this.addCharset(_charset);
			
			return jqtpl.tmpl( "headingTemplate", {
				title: _title,
				tags: _stack
				});
			
			},
		
		title: function(title) {
			_title = title;
			return this;
			},
		
		charset: function(charset) {
			_charset = charset;
			return this;
			},
		
		addJavascript: function(link) {			
			_stack.push({
				tag: 'script',
				close: true,
				attributes: {
					type: 'text/javascript',
					src: link
					}
				});
			return this;
			},
		
		addCharset: function(charset) {
			_charset = charset;
			_stack.push({
				tag: 'meta',
				close: false,
				attributes: {
					charset: _charset
					}
				});			
			return this;
			},
		
		addMeta: function(params) {			
			_stack.push({
				tag:'meta',
				close: false,
				attributes: params
				});			
			return this;
			},
		
		addDescription: function(description) {
			this.addMeta({
				name: 'description',
				content: description
				});
			return this;			
			},
		
		addLink: function(href,options) {
			_stack.push({
				tag:'link',
				close: true,
				attributes: {
					href: href,
					rel: options.rel,
					rev: options.rev,
					charset: options.charset,
					media: options.media,
					type: options.type,
					target: options.target
					}				
				});			
			return this;		
			},
		
		addPermalink: function(link) {
			this.addLink(link,{
				rel: 'permalink'
				});
			return this;
			},
		
		addAtom: function(href,title) {
			this.addLink(href,{
				rel: 'alternate',
				title: title != null ? title : _title,
				type: 'application/atom+xml'
				});
			return this;			
			}			

		};
	}; 

// exports to main
exports.meta = MetaManager;

==> metamanager-0.2.3.tgz: package/index.js <==
var MetaManager = function(jqtpl) {
	
	var _stack = [];
	var _title = '';
	var _charset = 'utf-8';
	var _tmpl = '<head>\n<title>${title}</title>\n'
		+'{{each(i,tag) tags}}'
		+'  <${tag}{{each(key,value) attributes}}{{if value != null}} ${key}="${value}"{{/if}}{{/each}}'
		+'{{if close && !content}}/{{/if}}>{{if close && content}}</${tag}>{{/if}}\n{{/each}}'
		+'</head>';
	
	jqtpl.template( "headingTemplate",_tmpl);

	function tagExists(tag,key,value) {
		return false;
		}
	
	return {
				
		get: function() {
			return _stack;
			},
		
		render: function() {
			
			// add standard tags
			if (!tagExists('meta','charset'))
				this.addCharset(_charset);
			
			return jqtpl.tmpl( "headingTemplate", {
				title: _title,
				tags: _stack
				});
			
			},
		
		title: function(title) {
			_title = title;
			return this;
			},
		
		charset: function(charset) {
			_charset = charset;
			return this;
			},
		
		// basic methods
		
		addJavascript: function(link) {			
			_stack.push({
				tag: 'script',
				close: true,
				content: true,
				attributes: {
					type: 'text/javascript',
					src: link
					}
				});
			return this;
			},


		addMeta: function(params) {			
			_stack.push({
				tag:'meta',
				close: false,
				content: false,
				attributes: params
				});			
			return this;
			},

		addLink: function(href,options) {
			_stack.push({
				tag:'link',
				close: true,
				content: false,
				attributes: {
					href: href,
					rel: options.rel,
					rev: options.rev,
					charset: options.charset,
					media: options.media,
					type: options.type,
					target: options.target
					}				
				});			
			return this;		
			},


		// common used methods
		
		
		addCharset: function(charset) {
			_charset = charset;

			this.addMeta({ charset: _charset });	

			return this;
			},		

		
		addDescription: function(description) {
			this.addMeta({
				name: 'description',
				content: description
				});
			return this;			
			},
		
		blog: {
				
			addPermalink: function(link) {
				this.addLink(link,{
					rel: 'permalink'
					});
				return this;
				},

			addAtom: function(href,title) {
				this.addLink(href,{
					rel: 'alternate',
					title: title != null ? title : _title,
					type: 'application/atom+xml'
					});
				return this;			
				}
				
			
			},
		
		
		facebook: {
			
			addDescription: function(description) {
				
				}
			
			
			}			

		};
	}; 

// exports to main
exports.meta = MetaManager;
